    processor 6502
    include vcs.h

;===============================================================================
; Z P - V A R I A B L E S
;===============================================================================

    SEG.U   variables
    ORG     $80

tmpVar      .byte
PlayerHand  .byte


;===============================================================================
; R O M - C O D E
;===============================================================================
    SEG     Bank0
    ORG     $f000

Start SUBROUTINE
    sei                         ;           Disable interrupts, if there are any.
    cld                         ;           Clear BCD math bit.
    ldx     #0
    txs
    pha                         ;           Set stack to beginning.
    txa
.clearLoop:
    pha
    dex
    bne     .clearLoop

    jsr     GameInit

.mainLoop:
    jsr     VerticalBlank
    jsr     GameCalc
    jsr     DrawScreen
    jsr     OverScan
    jmp     .mainLoop


GameInit SUBROUTINE
    rts


VerticalBlank SUBROUTINE
    lda     #2
    sta     WSYNC
    sta     VSYNC
    sta     WSYNC
    sta     WSYNC
    lsr
    ldx     #44
    sta     WSYNC
    sta     VSYNC
    stx     TIM64T
    rts


GameCalc SUBROUTINE
    rts


DrawScreen SUBROUTINE
    tsx
    stx     tmpVar

    ldx     #228
.waitTim:
    lda     INTIM
    bne     .waitTim
    sta     WSYNC
    sta     VBLANK
    stx     TIM64T
;---------------------------------------------------------------
.loopKernel:
;*******************************************************************************************
;Draw card boxes
DrawDr
     LDX #7             ;       Draw 7 cards on screen
     STX $81
     LDA #$34
     STA COLUP0         ;       Set color for card symbols to red
CardLoop
     LDX #11            ;       Each card "box" gets 11 scan lines
     STX $84            ;       Store 11 into $84 we will decrement this for loop count.
     LDA #$0F
     STA COLUPF         ;       Box is white
     TXA                ;       Load 11 into accumulator
     CLC                ;       Clear carry bit
     ADC $85            ;       Add the current card offset to the accumulator
     TAX                ;       Move accumulator back to X register
     LDX #59            ;       Used for debugging when X equates to this high, the kernel crashes.
                        ;        If below 50 the kernel functions fine.
InCardLoop              ;       Loop 11 times, drawing card symbol and white box.
     STA WSYNC
     LDA PlusFive,X
     STA GRP0
     LDA #%11100000
     STA PF2
     LDA $82            ;       $82 is enabled if the symbol sprite requires an extra pixel of data from the missle graphics.
                        ;       I have disabled this for testing.
     BEQ Nope
     LDA PlusFive,X
     STA ENAM0
     JMP Laa
Nope                    ;       Delay to make all the symbols line up correctly
     nop
     nop
     nop
     nop
Laa
     nop
     nop
     nop
     nop
     LDA #%00110000
     STA PF0
     STA RESP0          ;       Position Player graphic near middle of screen
     STA RESM0
     LDA #0
     STA PF2
     STA PF0
     STA ENAM0
     DEY                ;       Y contains scan lines remaining on screen.
     DEX                ;       X contains card offset index
     DEC $84            ;       $84 contains how many scan lines remaining for this card
     BNE InCardLoop

     STA WSYNC
     LDX #0
     STX $82            ;       Reset missile pixel
     STX GRP0
     LDX $81            ;       $81 contains how many cards are left to draw on screen
     DEX                ;       Decrement it
     LDA PlayerHand,X   ;       Load the players next card's offset index.
     STA $85
     STA WSYNC
     DEY                ;       Decrement Y twice because we used two scan lines here.
     DEY
     DEC $81            ;       Now decremement the current card count in memory.
     BNE CardLoop
;************************************************************



;---------------------------------------------------------------
    ldy     #0
    sty     PF0
    sty     PF1
    sty     GRP0
    sty     GRP1
    sty     ENAM0
    sty     ENAM1

    ldx     #2
.waitScreen:
    lda     INTIM
    bne     .waitScreen
    sta     WSYNC
    stx     VBLANK

    ldx     tmpVar
    txs
    rts


OverScan SUBROUTINE
    lda     #36
    sta     TIM64T

.waitTim:
    lda     INTIM
    bne     .waitTim
    rts


;===============================================================================
; R O M - T A B L E S (Bank 0)
;===============================================================================
    org     $ff00

PlusFive
 .byte $00,$00,$00,$0E,$42,$42,$EE,$48,$48,$0E,$00,$00
 .byte $00,$00,$00,$0B,$4B,$4A,$EA,$4A,$4B,$0B,$00,$00
 .byte $00,$00,$00,$0B,$4B,$4A,$EA,$4A,$4B,$0B,$00,$00
 .byte $00,$00,$00,$0E,$42,$42,$EE,$48,$48,$0E,$00,$00
 .byte $00,$00,$00,$0E,$42,$42,$EE,$48,$48,$0E,$00,$00
 .byte $00,$00,$00,$0B,$4B,$4A,$EA,$4A,$4B,$0B,$00,$00
 .byte $00,$00,$00,$0E,$42,$42,$EE,$48,$48,$0E,$00,$00
 .byte $00,$00,$00,$0B,$4B,$4A,$EA,$4A,$4B,$0B,$00,$00
 .byte $00,$00,$00,$0B,$4B,$4A,$EA,$4A,$4B,$0B,$00,$00


    org $fffc
    .word   Start
    .word   Start
